==> haskell-cipher-aes-0.2.11-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cipher-aes/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes
version: 0.2.11
id: cipher-aes-0.2.11-25252cf5003ba05bef45f1bdfd72c181
key: ciphe_8XNwNKI71EdCLNQ4WGdMQq
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cipher-aes
synopsis: Fast AES cipher implementation with advanced mode of operations
description:
    Fast AES cipher implementation with advanced mode of operations.
    .
    The modes of operations available are ECB (Electronic code book),
    CBC (Cipher block chaining), CTR (Counter), XTS (XEX with ciphertext stealing),
    GCM (Galois Counter Mode).
    .
    The AES implementation uses AES-NI when available (on x86 and x86-64 architecture),
    but fallback gracefully to a software C implementation.
    .
    The software implementation uses S-Boxes, which might suffer for cache timing issues.
    However do notes that most other known software implementations, including very popular
    one (openssl, gnutls) also uses similar implementation. If it matters for your
    case, you should make sure you have AES-NI available, or you'\''ll need to use a different
    implementation.
    .
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Cipher.AES
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cipher-aes-0.2.11
library-dirs: /usr/lib/ghc-7.10.3/site-local/cipher-aes-0.2.11
data-dir: /usr/share/arm-linux-ghc-7.10.3/cipher-aes-0.2.11
hs-libraries: HScipher-aes-0.2.11-8XNwNKI71EdCLNQ4WGdMQq
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    crypto-cipher-types-0.0.9-d75467a29912eeec0d085743eedba9cf
    securemem-0.1.9-b2776257967087e0982593cb67cce3c9
haddock-interfaces: /usr/share/doc/haskell-cipher-aes/html/cipher-aes.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cipher-aes-0.2.11-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cipher-aes/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes
version: 0.2.11
id: cipher-aes-0.2.11-78f8e669d2c7fa2c876e85f22e882b22
key: ciphe_4rzZveKsw1H0e7ZiE7LLYK
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cipher-aes
synopsis: Fast AES cipher implementation with advanced mode of operations
description:
    Fast AES cipher implementation with advanced mode of operations.
    .
    The modes of operations available are ECB (Electronic code book),
    CBC (Cipher block chaining), CTR (Counter), XTS (XEX with ciphertext stealing),
    GCM (Galois Counter Mode).
    .
    The AES implementation uses AES-NI when available (on x86 and x86-64 architecture),
    but fallback gracefully to a software C implementation.
    .
    The software implementation uses S-Boxes, which might suffer for cache timing issues.
    However do notes that most other known software implementations, including very popular
    one (openssl, gnutls) also uses similar implementation. If it matters for your
    case, you should make sure you have AES-NI available, or you'\''ll need to use a different
    implementation.
    .
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Cipher.AES
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cipher-aes-0.2.11
library-dirs: /usr/lib/ghc-7.10.3/site-local/cipher-aes-0.2.11
data-dir: /usr/share/arm-linux-ghc-7.10.3/cipher-aes-0.2.11
hs-libraries: HScipher-aes-0.2.11-4rzZveKsw1H0e7ZiE7LLYK
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    crypto-cipher-types-0.0.9-a95ebaba569741079643caffca2b7299
    securemem-0.1.9-01ec912d1ae68740f3ee3b7079e4f920
haddock-interfaces: /usr/share/doc/haskell-cipher-aes/html/cipher-aes.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
